@@ -1,6 +1,6 @@
 package PMLTQ::Suggest::Server;
 our $AUTHORITY = 'cpan:MATY';
-$PMLTQ::Suggest::Server::VERSION = '1.0.0';
+$PMLTQ::Suggest::Server::VERSION = '1.0.1';
 use base qw(HTTP::Server::Simple::CGI);
 use URI;
 use URI::file;
@@ -9,6 +9,7 @@ use PMLTQ::Suggest::Utils;
 use PMLTQ::Suggest;
 
 our $permitted_paths_re = '^(?:)/';
+our %methods = map {$_ => 1} qw/GET/;
 
 sub run {
     my $self = shift;
@@ -23,7 +24,8 @@ sub handle_request {
   my ($self, $cgi) = @_;
   eval {
       my $path = $cgi->path_info();
-      if ($path eq '/') {
+      my $method = $cgi->request_method();
+      if ($path eq '/' and exists($methods{$method})) {
           servePMLTQ($self,$cgi);
       } else {
           notFound($cgi);
